## 1.3.0.0 (2022-12-14)

Distribute our pika stubs under an alternate name (#9358)

Cf. #9246

## 1.3.0.0 (2022-11-23)

Disable pika uploads for now (#9257)

See #9246.

Further annotate pika (#9240)

Mark first argument of `__[get|set|del]attr__` as `str` (#9245)

Initial pika stubs (#9200)

